==> jppy_0.0.45.orig.tar.gz: jppy-0.0.45/python_module_src/move_into_libpisock.c <==
#include <pi-contact.h>
/* interestingly, pi-address.h needs stddef.h or to be after another header.. */
#include <pi-address.h>
#include <pi-todo.h>
#include <pi-memo.h>
#include <pi-datebook.h>
#include <pi-buffer.h>

#include "pytype_basics.h"

void new_Address(struct Address *a) {
  int i;
  /* Initialise attributes custom to this type of object */
  for (i=0;i<5;i++) {
    a->phoneLabel[i] = 0;
  }
  for (i=0;i<19;i++) {
    a->entry[i] = NULL;
  }
  a->showPhone    =  0;
}

void new_Contact(struct Contact *a) {
  int i;
  time_t now;
 
  /* Initialise attributes custom to this type of object */
  for (i=0;i<NUM_CONTACT_PHONES;i++) {
    a->phoneLabel[i] = 0;
  }
  for (i=0;i<3;i++) {
    a->addressLabel[i] = 0;
  }
  for (i=0;i<2;i++) {
    a->IMLabel[i] = 0;
  }
  for (i=0;i<NUM_CONTACT_ENTRIES;i++) {
    a->entry[i] = NULL;
  }
  a->showPhone    =  0;
  a->birthdayFlag =  0;
  a->reminder     = -1;
  
  a->pictype = cpic_none;
  a->picture = NULL;

  time( &now );
  a->birthday = *localtime( &now );
}

void new_ToDo(struct ToDo *a) {
  time_t now;
  /* Initialise attributes custom to this type of object */
  a->description = NULL;
  a->note = NULL;
  a->priority = 3;
  a->complete = 0;
  a->indefinite = 1;
  time( &now );
  a->due = *localtime( &now );   
}

void new_Memo(struct Memo *a) {
  a->text = NULL;
}

void new_Appointment(struct Appointment *a) {
  int i = 0;
  a->description = NULL;
  a->note = NULL;
  a->exceptions = 0;
  a->exception = NULL;
  a->event = 0;
  a->alarm = 0;
  a->advance = 0;
  a->advanceUnits = 0;
  a->repeatForever = 0;
  a->repeatFrequency = 0;
  a->repeatDay = 0;
  for (i = 0; i < 7; i++) {
    a->repeatDays[i] = 0;
  }
  a->repeatWeekstart = 0;
  a->exceptions = 0;
  a->begin.tm_hour        = 0;
  a->begin.tm_min         = 0;
  a->begin.tm_sec         = 0;
  a->begin.tm_year        = 2000;
  a->begin.tm_mon         = 0;
  a->begin.tm_mday        = 0;
  a->begin.tm_isdst       = -1;
  a->end.tm_hour        = 0;
  a->end.tm_min         = 0;
  a->end.tm_sec         = 0;
  a->end.tm_year        = 2000;
  a->end.tm_mon         = 0;
  a->end.tm_mday        = 0;
  a->end.tm_isdst       = -1;
}

==> jppy_0.0.56.orig.tar.gz: jppy-0.0.56/python_module_src/move_into_libpisock.c <==
#include "move_into_libpisock.h"

void new_Address(struct Address *a) {
  int i;
  /* Initialise attributes custom to this type of object */
  for (i=0;i<5;i++) {
    a->phoneLabel[i] = 0;
  }
  for (i=0;i<19;i++) {
    a->entry[i] = NULL;
  }
  a->showPhone    =  0;
}

void new_Contact(struct Contact *a) {
  int i;
  time_t now;
 
  /* Initialise attributes custom to this type of object */
  for (i=0;i<7;i++) {
    a->phoneLabel[i] = 0;
  }
  for (i=0;i<3;i++) {
    a->addressLabel[i] = 0;
  }
  for (i=0;i<2;i++) {
    a->IMLabel[i] = 0;
  }
  for (i=0;i<NUM_CONTACT_ENTRIES;i++) {
    a->entry[i] = NULL;
  }
  a->showPhone    =  0;
  a->birthdayFlag =  0;
  a->reminder     = -1;
  
  for (i=0;i<MAX_CONTACT_BLOBS;i++) {
    a->blob[i] = NULL;
  }
  a->picture = NULL;

  time( &now );
  a->birthday = *localtime( &now );
}

void new_ToDo(struct ToDo *a) {
  time_t now;
  /* Initialise attributes custom to this type of object */
  a->description = NULL;
  a->note = NULL;
  a->priority = 3;
  a->complete = 0;
  a->indefinite = 1;
  time( &now );
  a->due = *localtime( &now );   
}

void new_Memo(struct Memo *a) {
  a->text = NULL;
}

void new_Appointment(struct Appointment *a) {
  int i = 0;
  a->description = NULL;
  a->note = NULL;
  a->exceptions = 0;
  a->exception = NULL;
  a->event = 0;
  a->alarm = 0;
  a->advance = 0;
  a->advanceUnits = 0;
  a->repeatForever = 0;
  a->repeatFrequency = 0;
  a->repeatDay = 0;
  for (i = 0; i < 7; i++) {
    a->repeatDays[i] = 0;
  }
  a->repeatWeekstart = 0;
  a->exceptions = 0;
  a->begin.tm_hour        = 0;
  a->begin.tm_min         = 0;
  a->begin.tm_sec         = 0;
  a->begin.tm_year        = 2000;
  a->begin.tm_mon         = 0;
  a->begin.tm_mday        = 0;
  a->begin.tm_isdst       = -1;
  a->end.tm_hour        = 0;
  a->end.tm_min         = 0;
  a->end.tm_sec         = 0;
  a->end.tm_year        = 2000;
  a->end.tm_mon         = 0;
  a->end.tm_mday        = 0;
  a->end.tm_isdst       = -1;
}
